@@ -1,17 +1,14 @@
 use strict;
 package Email::Abstract::MIMEEntity;
-{
-  $Email::Abstract::MIMEEntity::VERSION = '3.006';
-}
 # ABSTRACT: Email::Abstract wrapper for MIME::Entity
-
+$Email::Abstract::MIMEEntity::VERSION = '3.010';
 use Email::Abstract::Plugin;
 BEGIN { @Email::Abstract::MIMEEntity::ISA = 'Email::Abstract::MailInternet' };
 
 my $is_avail;
 sub is_available {
   return $is_avail if defined $is_avail;
-  eval { require MIME::Entity; MIME::Entity->VERSION(5.501); 1 };
+  eval { require MIME::Entity; MIME::Entity->VERSION(5.508); 1 };
   return $is_avail = $@ ? 0 : 1;
 }
 
@@ -41,23 +38,46 @@ sub set_body {
 
 1;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This module wraps the MIME::Entity mail handling library with an
+#pod abstract interface, to be used with L<Email::Abstract>
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<Email::Abstract>, L<MIME::Entity>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Abstract::MIMEEntity - Email::Abstract wrapper for MIME::Entity
 
 =head1 VERSION
 
-version 3.006
+version 3.010
 
 =head1 DESCRIPTION
 
 This module wraps the MIME::Entity mail handling library with an
 abstract interface, to be used with L<Email::Abstract>
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 SEE ALSO
 
 L<Email::Abstract>, L<MIME::Entity>.
@@ -68,7 +88,7 @@ L<Email::Abstract>, L<MIME::Entity>.
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =item *
 
